@@ -1,5 +1,5 @@
 package SimpleDB::Client;
-our $VERSION = '1.0401';
+our $VERSION = '1.0402';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ SimpleDB::Client - The network interface to the SimpleDB service.
 
 =head1 VERSION
 
-version 1.0401
+version 1.0402
 
 =head1 SYNOPSIS
 
@@ -248,8 +248,13 @@ The L<HTTP::Response> object created by the C<send_request> method.
 sub handle_response {
     my ($self, $response) = @_;
     my $content = eval {XML::Bare::xmlin($response->content)};
-    if (exists $content->{SelectResult}{Item} && ref $content->{SelectResult}{Item} ne 'ARRAY') { # force an item list into an array
-          $content->{SelectResult}{Item} = [ $content->{SelectResult}{Item} ];
+    # compatibility with SimpleDB::Class
+    if (exists $content->{SelectResult} && $content->{SelectResult} == 1) {
+        $content->{SelectResult} = {};
+    }
+    # force an item list into an array
+    if (exists $content->{SelectResult}{Item} && ref $content->{SelectResult}{Item} ne 'ARRAY') { 
+         $content->{SelectResult}{Item} = [ $content->{SelectResult}{Item} ];
     }
 
     # choked reconstituing the XML, probably because it wasn't XML
